@@ -1,7 +1,7 @@
 import os
 from collections import OrderedDict
 
-__VERSION__ = "1.11.0"
+__VERSION__ = "1.12.1"
 __version__ = __VERSION__
 
 ASSAY_LIST = [
@@ -19,11 +19,13 @@ ASSAY_LIST = [
     'flv_CR',
     'convert10X',
     'flv_trust4',
+    'rna_virus',
+    'utils'
 ]
 
 ROOT_PATH = os.path.dirname(__file__)
 
-RELEASED_ASSAYS = ['rna', 'vdj', 'tag', 'dynaseq', 'snp', 'capture_virus', 'fusion', 'flv_CR', 'flv_trust4']
+RELEASED_ASSAYS = ['rna', 'vdj', 'tag', 'dynaseq', 'snp', 'capture_virus', 'fusion', 'citeseq', 'flv_CR', 'flv_trust4']
 
 # argument help
 HELP_DICT = {
