@@ -7,11 +7,11 @@ class Multi_dynaseq(Multi):
 
     """
     ## Usage
+
     ```
         multi_dynaseq\\
         --mapfile ./rna.mapfile\\
         --genomeDir /SGRNJ/Public/Database/genome/homo_mus\\
-        --STAR_param "--outFilterScoreMinOverLread 0.3 --outFilterMatchNminOverLread 0.3 --outSAMattributes MD"\\
         --strand /SGRNJ03/Public/Database/genome/gene.strandedness.csv
     ```
 
@@ -24,18 +24,28 @@ class Multi_dynaseq(Multi):
     ```
     """
 
+    def star(self, sample):
+        step = 'star'
+        fq = f'{self.outdir_dic[sample]["cutadapt"]}/{sample}_clean_2.fq{self.fq_suffix}'
+        cmd_line = self.get_cmd_line(step, sample)
+        cmd = (
+            f'{cmd_line} '
+            f'--fq {fq} '
+            f'--STAR_param "--outFilterScoreMinOverLread 0.3 --outFilterMatchNminOverLread 0.3 --outSAMattributes MD NH HI AS nM" '
+        )
+        self.process_cmd(cmd, step, sample, m=self.args.starMem, x=self.args.thread)
 
     def conversion(self, sample):
         step = 'conversion'
         bam = f'{self.outdir_dic[sample]["featureCounts"]}/{sample}_Aligned.sortedByCoord.out.bam.featureCounts.bam'
-        cell = f'{self.outdir_dic[sample]["count"]}/{sample}_{FILTERED_MATRIX_DIR_SUFFIX[0]}/{BARCODE_FILE_NAME[0]}'
+        cell = f'{self.outdir_dic[sample]["count"]}/{sample}_{FILTERED_MATRIX_DIR_SUFFIX[0]}/{BARCODE_FILE_NAME}'
         cmd_line = self.get_cmd_line(step, sample)
         cmd = (
             f'{cmd_line} '
             f'--bam {bam} '
             f'--cell {cell} '
         )
-        self.process_cmd(cmd, step, sample, m=5, x=1)
+        self.process_cmd(cmd, step, sample, m=8, x=1)
 
     def substitution(self, sample):
         step = 'substitution'
